@@ -71,6 +71,7 @@ namespace Banter
 		//
 		private Widget sidebar;
 		private Image avatarImage;
+		private Label myDisplayName;
 		private ComboBoxEntry statusComboBoxEntry;
 		
 		private Entry searchEntry;
@@ -435,9 +436,17 @@ namespace Banter
 			vbox.Show ();
 			hbox.PackStart (vbox, true, true, 0);
 			
-			vbox.PackStart (new Label (), true, true, 0);
+			myDisplayName = new Label ();
+			myDisplayName.Xalign = 0;
+			myDisplayName.UseUnderline = false;
+			myDisplayName.UseMarkup = true;
+			myDisplayName.Show ();
+			vbox.PackStart (myDisplayName, true, true, 0);
+			
+			statusComboBoxEntry = ComboBoxEntry.NewText ();
+			statusComboBoxEntry.KeyPressEvent += OnStatusComboKeyPress;
+			statusComboBoxEntry.Changed += OnStatusComboChanged;
 			
-			statusComboBoxEntry = new ComboBoxEntry ();
 			statusComboBoxEntry.Show ();
 			vbox.PackStart (statusComboBoxEntry, false, false, 0);
 			
@@ -445,6 +454,23 @@ namespace Banter
 			return hbox;
 		}
 		
+		private void OnStatusComboKeyPress (object sender, KeyPressEventArgs args)
+		{
+			if (args.Event.Key == Gdk.Key.Return) {
+				if (PersonStore.Me != null) {
+					Logger.Debug ("FIXME: Set \"my\" status to: {0}",
+							statusComboBoxEntry.ActiveText);
+					PersonStore.Me.Presence.Message =
+							statusComboBoxEntry.ActiveText;
+				}
+			}
+		}
+		
+		private void OnStatusComboChanged (object sender, EventArgs args)
+		{
+			Logger.Debug ("OnStatusComboChanged");
+		}
+		
 		private Widget CreateSidebarSearchEntry ()
 		{
 			VBox vbox = new VBox (false, 0);
@@ -656,6 +682,7 @@ Logger.Debug ("GroupWindow.BuildGroupButtonsView adding {0} groups",
 			Logger.Debug ("Adding group button: {0}", button.PersonGroup.DisplayName);
 			button.Show ();
 			button.Clicked += OnGroupButtonClicked;
+			button.DeleteClicked += OnGroupButtonDeleteClicked;
 			groupButtonsVBox.PackStart (button, false, false, 0);
 			groupButtonMap [path.Indices [0]] = button;
 		}
@@ -684,6 +711,9 @@ Logger.Debug ("GroupWindow.BuildGroupButtonsView adding {0} groups",
 		#region method overrides
 		protected override bool OnDeleteEvent (Gdk.Event evnt)
 		{
+			if (PersonStore.Me != null)
+				PersonStore.Me.PresenceUpdated -= OnMyPresenceUpdated;
+			
 			groupTreeModel.RowInserted -= OnGroupRowInserted;
 			groupTreeModel.RowDeleted -= OnGroupRowDeleted;
 			groupTreeModel.RowChanged -= OnGroupRowChanged;
@@ -700,6 +730,20 @@ Logger.Debug ("GroupWindow.BuildGroupButtonsView adding {0} groups",
 		#region event handlers
 		private void OnRealizeWidget (object sender, EventArgs args)
 		{
+			// Set "my" display name
+			Person me = PersonStore.Me;
+			if (me != null) {
+				myDisplayName.Markup =
+					string.Format (
+						"<span weight=\"bold\" size=\"small\">{0}</span>",
+						me.DisplayName);
+				
+				// Set "my" status
+				statusComboBoxEntry.AppendText (me.Presence.Message);
+				
+				me.PresenceUpdated += OnMyPresenceUpdated;
+			}
+			
 			// Fill out the existing groups
 			BuildGroupButtonsView ();
 			
@@ -756,22 +800,44 @@ Logger.Debug ("GroupWindow.BuildGroupButtonsView adding {0} groups",
 		
 		private void OnEveryoneClicked (object sender, EventArgs args)
 		{
-			Logger.Debug ("FIXME: Implement GroupWindow.OnEveryoneClicked ()");
-			
-//			if (Everyone isn't already selected) {
-
-			Title = Catalog.GetString ("Everyone - Banter");
-			selectedGroup = null;
-			
-			personView.Model = PersonStore.People;
-			
-			QueueSaveState ();
-//			}
+			if (selectedGroup != null) { // Everyone isn't already selected
+				Title = Catalog.GetString ("Everyone - Banter");
+				selectedGroup = null;
+				
+				personView.Model = PersonStore.People;
+				
+				QueueSaveState ();
+			}
 		}
 		
 		private void OnNewGroupClicked (object sender, EventArgs args)
 		{
-			Logger.Debug ("FIXME: Implement GroupWindow.OnNewGroupClicked ()");
+			HIGMessageDialog dialog =
+				new HIGMessageDialog (this, Gtk.DialogFlags.DestroyWithParent,
+					Gtk.MessageType.Question,
+					Gtk.ButtonsType.OkCancel,
+					Catalog.GetString ("New group window"),
+					Catalog.GetString ("Enter the name of the new group you'd like to create."));
+			
+			Gtk.Entry groupNameEntry = new Entry ();
+			dialog.ExtraWidget = groupNameEntry;
+			
+			int returnCode = dialog.Run ();
+			
+			if (returnCode == (int) Gtk.ResponseType.Ok) {
+				string groupName = groupNameEntry.Text.Trim ();
+				if (groupName.Length > 0) {
+					try {
+						PersonGroup group = new PersonGroup (groupName);
+						PersonStore.AddGroup (group);
+					} catch (Exception e) {
+						Logger.Debug ("Couldn't create a group: {0}\n{1}\n{2}",
+								groupName, e.Message, e.StackTrace);
+					}
+				}
+			}
+			
+			dialog.Destroy ();
 		}
 		
 		private void OnSettingsClicked (object sender, EventArgs args)
@@ -834,6 +900,11 @@ Logger.Debug ("GroupWindow.BuildGroupButtonsView adding {0} groups",
 			}
 		}
 		
+		private void OnMyPresenceUpdated (Person me)
+		{
+			statusComboBoxEntry.AppendText (me.Presence.Message);
+		}
+		
 		private void OnGroupRowInserted (object sender, RowInsertedArgs args)
 		{
 			PersonGroup group =
@@ -908,6 +979,30 @@ Logger.Debug ("GroupWindow.BuildGroupButtonsView adding {0} groups",
 			QueueSaveState ();
 		}
 		
+		private void OnGroupButtonDeleteClicked (GroupButton sender, PersonGroup group)
+		{
+			HIGMessageDialog dialog = new HIGMessageDialog (
+				this, DialogFlags.DestroyWithParent,
+				MessageType.Warning, ButtonsType.YesNo,
+				string.Format (
+					Catalog.GetString ("Delete \"{0}\"?"),
+					group.DisplayName),
+				Catalog.GetString ("This will delete the group and not the contacts inside of the group."));
+			int responseType = dialog.Run ();
+			dialog.Destroy ();
+			
+			if (responseType == (int) ResponseType.Yes) {
+				try {
+					PersonStore.RemoveGroup (group.Id);
+				} catch (Exception e) {
+					Logger.Warn ("Error removing the group: {0}\n{1}\n{2}",
+							group.DisplayName,
+							e.Message,
+							e.StackTrace);
+				}
+			}
+		}
+		
 		// <summary>
 		// Save the state of the window if its moved or resized.
 		// </summary> 
@@ -921,11 +1016,13 @@ Logger.Debug ("GroupWindow.BuildGroupButtonsView adding {0} groups",
 
 	public delegate void GroupButtonClickedHandler (GroupButton sender, PersonGroup group); 
 
-	public class GroupButton : VBox
+	public class GroupButton : HBox
 	{
 		private PersonGroup group;
 		private Label label;
 		private Button button;
+		private Button deleteButton;
+		private Image deleteImage;
 		
 		public GroupButton (PersonGroup personGroup)
 		{
@@ -944,8 +1041,18 @@ Logger.Debug ("GroupWindow.BuildGroupButtonsView adding {0} groups",
 			button.Relief = ReliefStyle.None;
 			button.Show ();
 			button.Clicked += OnButtonClicked;
+			PackStart (button, true, true, 0);
 			
-			Add (button);
+			deleteImage = new Image (Stock.Delete, IconSize.Menu);
+			deleteImage.NoShowAll = true;
+			deleteButton = new Button (deleteImage);
+			deleteButton.Relief = ReliefStyle.None;
+			deleteButton.Show ();
+			deleteButton.Clicked += OnDeleteButtonClicked;
+			deleteButton.Entered += OnDeleteButtonMouseEnter;
+			deleteButton.Left += OnDeleteButtonMouseLeft;
+			
+			PackStart (deleteButton, false, false, 0);
 		}
 		
 		public new void Show ()
@@ -954,6 +1061,7 @@ Logger.Debug ("GroupWindow.BuildGroupButtonsView adding {0} groups",
 		}
 		
 		public event GroupButtonClickedHandler Clicked;
+		public event GroupButtonClickedHandler DeleteClicked;
 		
 		public PersonGroup PersonGroup
 		{
@@ -970,10 +1078,26 @@ Logger.Debug ("GroupWindow.BuildGroupButtonsView adding {0} groups",
 		
 		private void OnButtonClicked (object sender, EventArgs args)
 		{
-			if (Clicked == null)
-				return;
-			
-			Clicked (this, group);
+			if (Clicked != null)
+				Clicked (this, group);
+		}
+		
+		private void OnDeleteButtonClicked (object sender, EventArgs args)
+		{
+			if (DeleteClicked != null)
+				DeleteClicked (this, group);
+		}
+		
+		private void OnDeleteButtonMouseEnter (object sender, EventArgs args)
+		{
+			Logger.Debug ("OnDeleteButtonMouseEnter");
+			deleteImage.Show ();
+		}
+		
+		private void OnDeleteButtonMouseLeft (object sender, EventArgs args)
+		{
+			Logger.Debug ("OnDeleteButtonMouseLeft");
+			deleteImage.Hide ();
 		}
 	}
 }
